summaryrefslogtreecommitdiffstats
path: root/chalk/ui/squeezedcombobox.h
diff options
context:
space:
mode:
Diffstat (limited to 'chalk/ui/squeezedcombobox.h')
-rw-r--r--chalk/ui/squeezedcombobox.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/chalk/ui/squeezedcombobox.h b/chalk/ui/squeezedcombobox.h
index 0ca7bb41..03a1cdb9 100644
--- a/chalk/ui/squeezedcombobox.h
+++ b/chalk/ui/squeezedcombobox.h
@@ -51,10 +51,10 @@ public:
* t = new SqueezedComboBoxTip( this->listBox()->viewport(), this );
* @endcode
*
* @param tqparent tqparent widget (viewport)
* @param name tqparent widget
*/
- SqueezedComboBoxTip( TQWidget *tqparent, SqueezedComboBox *name );
+ SqueezedComboBoxTip( TQWidget *parent, SqueezedComboBox *name );
protected:
/**
@@ -87,10 +87,10 @@ class SqueezedComboBox : public TQComboBox
public:
/**
* Constructor
* @param tqparent tqparent widget
* @param name name to give to the widget
*/
- SqueezedComboBox(TQWidget *tqparent = 0, const char *name = 0 );
+ SqueezedComboBox(TQWidget *parent = 0, const char *name = 0 );
/**
* destructor
@@ -51,10 +51,10 @@ public:
* @endcode
*
- * @param tqparent tqparent widget (viewport)
- * @param name tqparent widget
+ * @param parent parent widget (viewport)
+ * @param name parent widget
*/
@@ -87,10 +87,10 @@ class SqueezedComboBox : public TQComboBox
/**
* Constructor
- * @param tqparent tqparent widget
+ * @param parent parent widget
* @param name name to give to the widget
*/